function [ As,Bs,Cs,Ks,nSystems, niceBetaSelection ] = ExampleIEEETacExample1( )
%EXAMPLEIEEETACEXAMPLE1 Data for the first numerical example from Baştuǧ 
% et. al, 2016, IEEE Transaction on Automatic Control, vol. 61, no. 11, 
% pp. 3422-3437.
%
% The data is taken from https://kom.aau.dk/~mertb/
%
% % Output arguments:
%   As:                 cell array of length 2 containing the A matrices
%   Bs:                 cell array of length 2 containing the B matrices
%   Cs:                 cell array of length 2 containing the C matrices
%   Ks:                 2 x 2 cell containing transition matrices between 
%                       the subsystems (all identity matrices)
%   nSystems:           number of subsystems = 2
%   niceBetaSelection:  the nice beta selection provided in the cited paper
%
% Required files:
%   ExampleIEEETacExample1.mat
%
% Authors:
%   Philipp Schulze, pschulze@math.tu-berlin.de
%   Benjamin Unger, unger@math.tu-berlin.de
%
% Version:
%   1.0 (January, 2018)

    load('ExampleIEEETacExample1.mat');
    % this file contains the matrices A,B,C and the nice selection
    % NDFA_beta
    
    nSystems    = length(A) ;
    As          = cell(nSystems,1) ;
    Bs          = cell(nSystems,1) ;
    Cs          = cell(nSystems,1) ;
    for i=1:nSystems
        As{i}   = A(i).value ;
        Bs{i}   = B(i).value ;
        Cs{i}   = C(i).value ;
    end
    
    dimFOM      = size(As{1}) ;
    Ks          = {{speye(dimFOM) speye(dimFOM)},{speye(dimFOM) speye(dimFOM)}} ; 
    niceBetaSelection = NDFA_beta ;
end

